@@ -4,9 +4,9 @@
 
 #include "savedcolormodel.h"
 
-#include <QCoreApplication>
 #include <QDebug>
 #include <QDir>
+#include <QGuiApplication>
 #include <QSqlError>
 #include <QSqlQuery>
 #include <QSqlRecord>
@@ -24,7 +24,7 @@ SavedColorModel::SavedColorModel(QObject *parent)
     DatabaseConfiguration config;
     config.setType(DatabaseType::SQLite);
     config.setDatabaseName(
-        QDir::cleanPath(QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) % QDir::separator() % qApp->applicationName()));
+        QDir::cleanPath(QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) % QDir::separator() % qGuiApp->applicationName()));
 
     m_database = ThreadedDatabase::establishConnection(config);
     m_database->runMigrations(QStringLiteral(":/contents/migrations/"));
